# dyte_core

<!-- PROJECT LOGO -->
<p align="center">
  <a href="https://dyte.in">
    <img src="https://dyte-uploads.s3.ap-south-1.amazonaws.com/dyte-logo-dark.svg" alt="Logo" width="80">
  </a>
  <h3 align="center">Dyte Flutter Core</h3>

  <p align="center">
    A SDK that provides Dyte's audio, video conferencing and livestreaming functionality.
    <br />
    <a href="https://docs.dyte.io/flutter-core"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    ·
    <a href="https://docs.dyte.io/discuss">Report Bug</a>
    ·
    <a href="https://docs.dyte.io/discuss">Request Feature</a>
  </p>
</p>

## Before Getting Started

- Make sure you've read the
  [Getting Started with Dyte](https://docs.dyte.io/getting-started) topic and
  completed the steps in the
  [Integrate Dyte](https://docs.dyte.io/getting-started#integrate-dyte) section.
  You must complete the following steps:
  - Create a [Dyte Developer Account](https://dev.dyte.io/)
  - Create [Presets](https://dev.dyte.io/roles-presets)
  - Create a
    [Dyte Meeting](https://docs.dyte.io/api/?v=v2#/operations/create_meeting)
  - [Add Participant](https://docs.dyte.io/api/?v=v2#/operations/add_participant)
    to the meeting

## Installation

```sh
flutter pub add dyte_core
```

### For iOS

1. Set your platform to iOS 12.0 or above in your Podfile.

```dart
platform :ios, '12.0'
```

2. Add the following entries to the `info.plist` file. This gives permission to
   your app to access the camera and microphone, access photos, install the
   required fonts and icons.

```dart
<key>NSBluetoothPeripheralUsageDescription</key>
<string>We will use your Bluetooth to access your Bluetooth headphones.</string>
<key>NSBluetoothAlwaysUsageDescription</key>
<string>We will use your Bluetooth to access your Bluetooth headphones.</string>
<key>NSCameraUsageDescription</key>
<string>For people to see you during meetings, we need access to your camera.</string>
<key>NSMicrophoneUsageDescription</key>
<string>For people to hear you during meetings, we need access to your microphone.</string>
<key>NSPhotoLibraryUsageDescription</key>
<string>For people to share, we need access to your photos.</string>
```

<!-- USAGE EXAMPLES -->
## Usage

### Import the following package into your project:

```dart
import 'package:dyte_core/dyte_core.dart';
```

### Initialize the SDK

The `DyteMobileClient` is the main class of the SDK. It is the entry point and
the only class required to initialize Dyte SDK.

```dart
final dyteClient = DyteMobileClient();
```

### Set the meeting properties

Set the properties in the `DyteMeetingInfo` class. You just need to provide the
participant's `authToken`.

| Name        | Description                                                                                                                                                                                                                                                                                                                                   |
| ----------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `authToken` | After you've created the meeting, <br/> add each participant to the meeting <br/> using the [Add Participant API](https://docs.dyte.io/api?v=v2#/operations/add_participant)<br/> (The presetName created earlier <br/> must be passed in the body <br/> of the Add Participant API request) <br/> The API response contains the `authToken`. |

```dart
final meetingInfo = DyteMeetingInfoV2(
                    authToken: '<auth_token>',
                  );
```

### Initialize the connection request

To initialize the connection request, call the `init()` method obtained on
`dyteClient` with the `meetingInfo` argument. This will establish the connection
with the Dyte meeting server.

```dart
dyteClient.init(meetingInfo);
```

By registering state observers, you receive callbacks for this action on the
meeting object.

```dart

class RoomStateNotifier extends DyteMeetingRoomEventsListener {

  ...

  @override
  void onMeetingInitStarted() {
    /// on meeting init started
  }

  override
  void onMeetingInitCompleted() {
    /// on meeting init completed
  }

  @override
  void onMeetingInitFailed(Exception exception) {
    /// on meeting init failed
  }

  ...
}

```

### Connect to the meeting

Now, you have established the connection with the Dyte meeting server
successfully. Next step is to join the room.

#### Join the room

To join the meeting room, call `joinRoom()` method on the `dyteClient` instance
as shown below.

```dart
dyteClient.joinRoom();
```

By registering state observers, you receive callbacks for this action on the
meeting object.

```dart
class LocalUserStatesNotifier extends DyteSelfEventsListener {

  @override
  void onMeetingRoomJoinStarted() {
    /// Handle join start state
  }

  @override
  void onMeetingRoomJoined () {
    /// Handle joining completion, ex: move to room screen
  }

  @override
  void onMeetingRoomJoinFailed(exception){
    /// Handle failure
  }

}
```

#### Leave the room

Once the meeting is over, you can leave the meeting room.

To leave the meeting room, call `leaveRoom()` method on the `dyteClient` as
shown below.

```dart
dyteClient.leaveRoom();
```

By registering state observers, you receive callbacks for this action on the
meeting object.

```dart
class RoomStateNotifier extends DyteMeetingRoomEventsListener {

  ...

  @override
  void onMeetingRoomLeaveStarted() {
    /// on meeting room leave started
  }

  @override
  void onMeetingRoomLeft() {
    /// on meeting room left
  }

  ...

}
```

_For more examples, please refer to the [Documentation](https://docs.dyte.io/flutter-core)._

## About

`dyte_core` is created & maintained by Dyte, Inc. You can find us on Twitter - [@dyte_io](https://twitter.com/dyte_io) or write to us at `dev@dyte.io`.

The names and logos for Dyte are trademarks of Dyte, Inc.

We love open source software! See [our other projects](https://github.com/dyte-in) and [our products](https://dyte.io).

